@@ -56,6 +56,7 @@ POSSIBILITY OF SUCH DAMAGE.
 #ifdef WITH_BROKER
 #  include <mqtt3.h>
    extern uint64_t bytes_received;
+   extern uint64_t bytes_sent;
    extern unsigned long msgs_received;
    extern unsigned long msgs_sent;
 #else
@@ -128,7 +129,15 @@ int _mosquitto_packet_queue(struct mosquitto *mosq, struct _mosquitto_packet *pa
 	}else{
 		mosq->out_packet = packet;
 	}
+#ifdef WITH_BROKER
 	return _mosquitto_packet_write(mosq);
+#else
+	if(mosq->in_callback == false){
+		return _mosquitto_packet_write(mosq);
+	}else{
+		return MOSQ_ERR_SUCCESS;
+	}
+#endif
 }
 
 /* Close a socket associated with a context and set it to -1.
@@ -433,6 +442,9 @@ int _mosquitto_packet_write(struct mosquitto *mosq)
 		while(packet->to_process > 0){
 			write_length = _mosquitto_net_write(mosq, &(packet->payload[packet->pos]), packet->to_process);
 			if(write_length > 0){
+#ifdef WITH_BROKER
+				bytes_sent += write_length;
+#endif
 				packet->to_process -= write_length;
 				packet->pos += write_length;
 			}else{
@@ -458,7 +470,9 @@ int _mosquitto_packet_write(struct mosquitto *mosq)
 #else
 		if(((packet->command)&0xF6) == PUBLISH && mosq->on_publish){
 			/* This is a QoS=0 message */
+			mosq->in_callback = true;
 			mosq->on_publish(mosq->obj, packet->mid);
+			mosq->in_callback = false;
 		}
 #endif
 
